﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace PovrchAObjemKoule
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// Statická třída obsahující deklaraci všech potřebných konstant
        /// </summary>
        static class Constants
        {
            public const string ZadPolomer = "Zadejte poloměr";
        }


        public MainWindow()
        {
            InitializeComponent();
            TxtPolomer.Text = Constants.ZadPolomer;
        }

        private void BtnKonec_Click(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void TxtPolomer_GotFocus(object sender, RoutedEventArgs e)
        {
            if (TxtPolomer.Text == Constants.ZadPolomer)
            {
                TxtPolomer.Text = string.Empty;
            }
        }

        private void TxtPolomer_LostFocus(object sender, RoutedEventArgs e)
        {
            if (TxtPolomer.Text == string.Empty)
            {
                // vyplnění políčka pro poloměr textem proměnné ZadPolomer
                TxtPolomer.Text = Constants.ZadPolomer;
                // vymazání výsledků předchozích výpočtů
                TxtPovrch.Text = "";
                TxtObjem.Text = "";
            }
        }

        private void BtnMetoda_Click(object sender, RoutedEventArgs e)
        {
            // Deklarace lokálních proměnných: s - povrch koule, v - objem koule
            double s, v;

            if (double.TryParse(TxtPolomer.Text, out double r))
            {
                // výpočet povrchu pomocí konstanty PI
                s = 4 * Math.PI * r * r;
                // výpočet objemu s pomocí metody POW
                v = ((double)4 / 3) * Math.PI * Math.Pow(r, 3);

                // vypsání s, v do textboxů
                TxtPovrch.Text = s.ToString();
                TxtObjem.Text = v.ToString();

            }
            // když se nepovede převod textu z GUI na číslo, tak ukážeme warning
            else
            {
                MessageBox.Show("Zadejte číslo ve správném formátu!", "Chyba", MessageBoxButton.OK, MessageBoxImage.Warning);
                TxtPolomer.Focus();
            }



        }

        #region Výpočty

        /// <summary>
        /// Metoda s návratem pro výpočet povrchu koule
        /// </summary>
        /// <param name="r"> poloměr koule - vstupní parametr metody</param>
        /// <returns>výstup je povrch koule (double)</returns>
        private double PovrchKouleMetodaSNavratem(double r)
        {
            return (4 * Math.PI * Math.Pow(r, 2));
        }

        /// <summary>
        /// Metoda s návratem pro výpočet objemu koule
        /// </summary>
        /// <param name="r"> poloměr koule - vstupní parametr metody</param>
        /// <returns>výstup je objem koule (double)</returns>
        private double ObjemKouleMetodaSNavratem(double r)
        {
            return (4d/3 * Math.PI * Math.Pow(r, 3));
        }

        #endregion

        private void BtnMetodaNavrat_Click(object sender, RoutedEventArgs e)
        {
            // parsuju text na číslo
            if (double.TryParse(TxtPolomer.Text, out double r))
            {
                //když se parsování povede, zavolám metody a předám jim parametr r
                TxtPovrch.Text = PovrchKouleMetodaSNavratem(r).ToString();
                TxtObjem.Text = ObjemKouleMetodaSNavratem(r).ToString();
            }
            // když se nepovede převod textu z GUI na číslo, tak ukážeme warning
            else
            {
                MessageBox.Show("Zadejte číslo ve správném formátu!", "Chyba", MessageBoxButton.OK, MessageBoxImage.Warning);
                TxtPolomer.Focus();
            }
        }
    }
}
